@@ -34,95 +34,91 @@ class RightlyComponent:
             _component_func = components.declare_component("rightly_component", path=build_dir)
         return _component_func
 
-    def initEvent(self):
-        if 'init_event' in st.session_state:
-            return
-        st.session_state['init_event'] = True
+    def init_event(self):
         components.html('''
             <script>
+                // hide-iframe
                 let listerens = [];
                 window.parent.addEventListener('message', (event) => {
                     const { type } = event.data;
+                    console.log('[event]', event);
                     if (type === 'component-message-dispatch') {
                         // 广播
-                        console.log('[dispatch]');
                         listerens.forEach(listeren => listeren.postMessage(event.data, '*'))
                     }
                     if (type === 'component-message-listeren') {
-                        console.log('[listeren]');
                         listerens.push(event.source);
                     }
                 });
-                const iframs = window.parent.document.getElementsByTagName('iframe');
-                Array.from(iframs).forEach(iframe => {
+                const iframes = window.parent.document.getElementsByTagName('iframe');
+                Array.from(iframes).forEach(iframe => {
                     const srcdoc = iframe.srcdoc;
-                    if (srcdoc.includes('window.parent.document')) {
-                        iframe.style.display = 'none';
+                    if (srcdoc.includes('hide-iframe')) {
+                        iframe.parentNode.style.display = 'none';
                     }
                 })
             </script>
         ''')
 
+    def init_style(self):
+        components.html('''
+            <script>
+                // hide-iframe
+                const d = window.parent.document;
+                d.getElementsByClassName('main')[0].style.overflow = 'hidden';
+                d.getElementsByTagName('header')[0].style.display = 'none';
+                d.getElementsByTagName('footer')[0].style.display = 'none';
+                d.body.style.height = '100%';
+                d.body.parentElement.style.height = '100%';
+                const container = d.getElementsByClassName('block-container')[0];
+                container.style.maxWidth = '100%';
+                container.style.padding = '0';
+                
+                const iframes = window.parent.document.getElementsByTagName('iframe');
+                Array.from(iframes).forEach(iframe => {
+                    const srcdoc = iframe.srcdoc;
+                    if (srcdoc.includes('hide-iframe')) {
+                        iframe.parentNode.style.display = 'none';
+                    }
+                })
+
+                window.parent.addEventListener('message', (event) => {
+                    const { type } = event.data;
+                    if (type === 'get_client_height') {
+                        // 广播
+                        event.source.postMessage({
+                            type: 'set_height',
+                            data: window.parent.document.body.clientHeight,
+                        }, '*')
+                    }
+                    if (type === 'get_iframe') {
+                        const iframes = window.parent.document.getElementsByTagName('iframe');
+                        const filter = Array.from(iframes).filter(iframe => {
+                            return iframe.contentWindow == event.source
+                        });
+                        if (filter[0]) {
+                            const doc = filter[0];
+                            const fn = new Function('doc', event.data.data);
+                            fn(doc);
+                        }
+                    }
+                });
+            </script>
+        ''')
+
     def rightly_component(self, component_name, data = {}, default = {}, key = None, events = None):
-        if events is not None:
-            self.initEvent()
         component_value = self._component_func(componentName=component_name, data=data, key=key or component_name, default=default, events=events)
         # We could modify the value returned from the component if we wanted.
         # There's no need to do this in our simple example - but it's an option.
+        if component_value and isinstance(component_value, dict) and "time" in component_value:
+            if component_value["time"] == st.session_state.get(f'_component_value_{key}'):
+                component_value["value_is_change"] = False
+            else:
+                st.session_state[f'_component_value_{key}'] = component_value["time"]
+                component_value["value_is_change"] = True
+                
         return component_value
 
-    def modal():
-        st.markdown('<div id="modal-mask"></div>', unsafe_allow_html=True)
-        components.html('''
-            <script>
-                var d = window.parent.document;
-                var b = d.getElementById('modal-mask');
-                var c = b.parentNode.parentNode.parentNode.parentNode;
-                c.id += 'modal';
-                console.log(c.className)
-            </script>
-        ''')
-        st.write('''<style>
-            #modal {
-                position: fixed;
-                left: 0;
-                top: 0;
-                z-index: 900;
-                width: 100%;
-                height: 100%;
-            }
-
-            #modal > div:nth-child(-n + 3) {
-                display: none;
-            }
-
-            #modal > div:first-child {
-                display: block;
-                width: 100%;
-                height: 100%;
-                background: rgba(333, 333, 333, 0.5);
-            }
-
-            #modal > div:nth-child(4) {
-                position: absolute;
-                width: 600px;
-                left: 50%;
-                top: 50%;
-                z-index: 1;
-                transform: translate(-50%, -50%);
-            }
-            
-            </style>''', unsafe_allow_html=True)
-        
-        close = st.button('关闭浮层')
-        if close:
-            st.write('''<style>#modal {
-                        display: none;
-                    }</style>''', unsafe_allow_html=True)
-            return {"action": "close"}
-
-        return None
-
 
 instance = RightlyComponent()
 
@@ -132,6 +128,10 @@ def rightly_component(component_name, data = {}, default = None, key = None, eve
 def set_debug(release = False, url = 'http://localhost:3001'):
     return instance.set_debug(release, url)
 
+def init_component():
+    instance.init_event()
+    instance.init_style()
+
 class modal:
     def __init__(self, close_fn = None):
         self.action = None
@@ -159,7 +159,7 @@ class modal:
             
             #modal {
                 display: block;
-                position: fixed;
+                position: absolute;
                 left: 0;
                 top: 0;
                 z-index: 900;
@@ -207,13 +207,15 @@ class modal:
             #modal > div:nth-child(4) > div {
                 display: block;
                 position: absolute;
-                width: 90%;
-                left: 50%;
-                top: 50%;
+                width: 100%;
+                left: 0;
+                height: 80%;
+                bottom: 0;
                 z-index: 1;
-                transform: translate(-50%, -50%);
                 background: #fff;
                 padding: 20px;
+                overflow-x: hidden;
+                overflow-y: auto;
             }
             
             </style>''', unsafe_allow_html=True)
